import { postMessage } from "@/helpers/native-message";
import { NavBar } from "vant";
import { defineComponent } from "vue";
import styles from './index.module.less'

type backIconColor = 'black' | 'white';
type backgroundType = 'white' | 'green';

export default defineComponent({
  name: "col-header",
  props: {
    title: String,
    isBack: {
      type: Boolean,
      default: false
    },
    isFixed: {
      type: Boolean,
      default: true
    },
    styleName: {
      type: Object,
      default: () => ({})
    },
    titleClass: String,
    background: {
      type: String,
      default: 'white' as backgroundType
    },
    rightText: String,
    onClickRight: {
      type: Function,
      default: () => { }
    }
  },
  data() {
    return {
      headerTitle: null as any,
      navBarHeight: 0, // 顶部导航栏高度
      titleHeight: 44, // 顶部导航高度（默认44px）
    }
  },
  mounted() {
    this.headerTitle = this.title || this.$route.meta.title;
    this.navBarInit();
  },
  unmounted() {
    // 设置是否显示导航栏 0 显示 1 不显示
    postMessage({ api: 'setBarStatus', content: { status: 1 } })
    // 设置返回按钮颜色
    postMessage({ api: 'backIconChange', content: { iconStyle: 'white' as backIconColor } })
  },
  methods: {
    navBarInit() {
      // 设置是否显示导航栏 0 显示 1 不显示
      postMessage({ api: 'setBarStatus', content: { status: 0 } })
      // 设置返回按钮颜色
      postMessage({ api: 'backIconChange', content: { iconStyle: 'black' as backIconColor } })

      let sNavHeight = sessionStorage.getItem('navHeight')
      let sTitleHeight = sessionStorage.getItem('titleHeight')
      if (sNavHeight && sTitleHeight) {
        this.navBarHeight = Number(sNavHeight)
      } else {
        postMessage({ api: 'getNavHeight' }, (res) => {
          const { content } = res as any
          const dpi = content.dpi || 2
          if (content.navHeight) {
            const navHeight = content.navHeight / dpi
            sessionStorage.setItem('navHeight', String(navHeight))
            this.navBarHeight = navHeight
          }
          if (content.titleHeight) { // 导航栏的高度
            const titleHeight = content.titleHeight / dpi
            sessionStorage.setItem('titleHeight', String(titleHeight))
            this.titleHeight = titleHeight
          }
        })
      }
    },
    onClickLeft() {
      this.$router.back();
    },
    clickRight() {
      this.onClickRight && this.onClickRight();
    }
  },
  render() {
    return (
      <>
        {this.$slots.content ?
          <div style={{ paddingTop: `${this.navBarHeight}px` }} class={styles.headerSection}>
            {this.$slots.content()}
          </div> :
          <><div style={{ paddingTop: `${this.navBarHeight}px` }} class={styles.headerSection}>
            <NavBar title={this.headerTitle}
              style={{ height: this.titleHeight + 'px', lineHeight: this.titleHeight + 'px' }}
              class={[this.background === 'green' ? styles.green : null, styles.colHeader]}
              left-arrow={this.isBack}
              rightText={this.rightText}
              fixed={this.isFixed}
              onClick-right={this.clickRight}
              onClick-left={this.onClickLeft}></NavBar>
          </div>
            {this.$slots.default ? this.$slots.default() : null}</>}
      </>
    )
  }
})