import { defineComponent } from "vue";
import { Button, Image, Toast } from 'vant';
import styles from './index.module.less';
import request from "@/helpers/request";
import { state } from "@/state";
import ColResult from "@/components/col-result";

export default defineComponent({
  name: 'music-cert',
  data() {
    return {
      authStatus: null
    }
  },
  mounted() {
    if (state.user.data?.musicianAuthStatus) {
      state.musicCertStatus = !!state.user.data.musicianAuthStatus
    }
  },
  methods: {
    async onClick() {
      try {
        await request.post('/api-teacher/teacherAuthMusicianRecord/doApply', {})
        Toast('申请认证成功')
        state.musicCertStatus = true
      } catch {
        //
      }
    }
  },
  render() {
    return (
      <>
        {
          state.musicCertStatus ? <ColResult tips="您已成功提交音乐人认证申请我们将在2个工作日内与您取得联系" /> : <div class={styles['music-cert']}>
            <h2>音乐人认证是什么？</h2>
            <p class={styles['cert-text']}>
              酷乐秀对有能力编曲的音乐人开通上传曲谱权限，开通后您可上传自己编曲的乐谱MIDI让平台学员进行练习，并获取收益
            </p>
            <p class={styles['cert-img']}>
              <Image src="https://daya.ks3-cn-beijing.ksyun.com/202110/Sn76BUQ.png" width="100%" height="150px" fit="cover" />
            </p>

            <h2>MIDI文件上传</h2>
            <p class={styles['cert-text']}>
              您可上传自己编曲的乐谱MIDI，并自定义乐谱价格，为平台学员提供智能陪练练习
            </p>
            <p class={styles['cert-img']}>
              <Image src="https://daya.ks3-cn-beijing.ksyun.com/202110/Sn76BUQ.png" width="100%" height="150px" fit="cover" />
            </p>

            <h2>乐谱收益</h2>
            <p class={styles['cert-text']}>
              您可对上传的乐谱自定义价格，学员可自行挑选乐谱购买，购买后您将获取学员购买收入。
            </p>
            <p class={styles['cert-img']}>
              <Image src="https://daya.ks3-cn-beijing.ksyun.com/202110/Sn76BUQ.png" width="100%" height="150px" fit="cover" />
            </p>

            <div class={styles["btn-group"]}>
              <Button round block type="primary" disabled={this.authStatus === '1'} onClick={this.onClick}>立即认证</Button>
            </div>
          </div>
        }

      </>
    )
  }
})