import { defineComponent } from 'vue'
import { Button, Field, Sticky, Form } from 'vant'
import ColArea from '@/components/col-area'
import { MusicType } from 'src/teacher/music/list/item.d'
import ColField from '@/components/col-field'
import styles from './index.module.less'

export default defineComponent({
  name: 'MusicUpload',
  data() {
    return {
      musicSheetName: '',
      selectTagVisible: false
    }
  },
  methods: {
    submit(vals: any) {
      console.log(vals)
    },
    failed() {
      console.log('failed', this.musicSheetName)
    }
  },
  render() {
    return (
      <Form onSubmit={this.submit} onFailed={this.failed}>
        <div class={styles.container}>
          <ColArea class={styles.area}>
            <ColField required title="曲目名称">
              <Field
                name="musicSheetName"
                modelValue={this.musicSheetName}
                rules={[{ required: true, message: '请输入曲目名称' }]}
                class={styles['clear-px']}
                placeholder="请输入曲目名称"
                onUpdate:modelValue={val => (this.musicSheetName = val)}
              />
            </ColField>
            <ColField required title="作曲人">
              <Field
                class={styles['clear-px']}
                placeholder="请输入作曲人姓名"
              />
            </ColField>
          </ColArea>
          <ColArea class={styles.area}>
            <ColField
              required
              title="曲目标签"
              v-slos={{
                right: () => (
                  <Button
                    class={styles.select}
                    round
                    type="primary"
                    size="small"
                    onClick={() => (this.selectTagVisible = true)}
                  >
                    选择
                  </Button>
                )
              }}
            >
              <Field class={styles['clear-px']} placeholder="请输入曲目名称" />
            </ColField>
          </ColArea>
          <ColArea class={styles.area}>
            <ColField required title="默认速度">
              <Field class={styles['clear-px']} placeholder="请输入默认速度" />
            </ColField>
          </ColArea>
          <ColArea class={styles.area}>
            <ColField required title="默认速度">
              <Field class={styles['clear-px']} placeholder="请输入默认速度" />
            </ColField>
          </ColArea>
          <ColArea class={styles.area}>
            <ColField required title="默认速度">
              <Field class={styles['clear-px']} placeholder="请输入默认速度" />
            </ColField>
          </ColArea>
          <ColArea class={styles.area}>
            <ColField required title="收费价格">
              <Field class={styles['clear-px']} placeholder="请输入收费价格" />
            </ColField>
          </ColArea>
          <div class={styles.rule}>
            <p>扣除手续费后该曲目预计收入为：</p>
            <p>
              单课时：<span>5.8</span>元/人
            </p>
            <p>您的乐谱收入将在学员购买后结算到您的账户中</p>
          </div>
        </div>
        <Sticky offsetBottom={0} position="bottom">
          <div class={styles['button-area']}>
            <Button type="primary" block round native-type="submit">
              确认
            </Button>
          </div>
        </Sticky>
      </Form>
    )
  }
})
