import { Button, Checkbox, CheckboxGroup, Icon, Image, Loading } from "vant";
import { defineComponent } from "vue";
import styles from './subject-model.module.less';

import checkBoxActive from '../images/checkbox_active.png';
import checkBoxDefault from '../images/checkbox_default.png';
import ColResult from "@/components/col-result";

export default defineComponent({
  name: "subject-model",
  props: {
    onChoice: {
      type: Function,
      default: (item: any) => { }
    },
    choiceSubjectIds: {
      type: Array,
      default: []
    },
    subjectList: {
      type: Array,
      default: []
    },
    max: {// 最多可选数量
      type: Number,
      default: 5
    }
  },
  data() {
    return {
      checkBox: [],
      checkboxRefs: [] as any,
    }
  },
  async mounted() {
    this.checkBox = this.choiceSubjectIds as never[]
  },
  methods: {
    onSelect(id: number) {
      this.checkboxRefs[id].toggle();
    }
  },
  render() {
    return (
      <div class={styles.subjects}>
        {this.subjectList.length ? <CheckboxGroup v-model={this.checkBox} max={this.max}>
          {this.subjectList.map((item: any) => (
            <>
              <div class={styles.title}>{item.name}</div>
              <div class={styles['subject-list']}>
                {item.subjects && item.subjects.map((sub: any) => (
                  <div class={styles['subject-item']} onClick={() => this.onSelect(sub.id)}>
                    <Image src={sub.img} width="100%" height="100%" fit="cover" v-slots={{
                      loading: () => <Loading type="spinner" size={20} />
                    }} />
                    <div class={styles.topBg}>
                      <Checkbox name={sub.id} class={styles.checkbox} ref={(el: any) => this.checkboxRefs[sub.id] = el} v-slots={{
                        icon: (props: any) => (
                          <Icon name={props.checked ? checkBoxActive : checkBoxDefault} size="22" />
                        )
                      }} />
                      <p class={styles.name}>{sub.name}</p>
                    </div>
                  </div>
                ))}
              </div>
            </>
          ))}
        </CheckboxGroup> : <ColResult tips="暂无声部数据" btnStatus={false} />}

        <div class={styles["btn-group"]}>
          <Button round block type="primary" onClick={() => this.onChoice(this.checkBox)}>确定</Button>
        </div>
      </div>
    )
  }
})